==> eiffelstudio-18.11.10.2592.tar: F_code/C9/de445.c <==
/*
 * Code for class DESCENDANTS_FILTER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "de445.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {DESCENDANTS_FILTER}.make */
void F502_7055 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REAL_64 tr8_1;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	tr8_1 = (EIF_REAL_64) (((EIF_INTEGER_32) -1L));
	*(EIF_REAL_64 *)(Current+ _R64OFF_5_0_0_0_0_0_0_0_) = (EIF_REAL_64) tr8_1;
	tr8_1 = (EIF_REAL_64) (((EIF_INTEGER_32) -1L));
	*(EIF_REAL_64 *)(Current+ _R64OFF_5_0_0_0_0_0_0_2_) = (EIF_REAL_64) tr8_1;
	tr8_1 = (EIF_REAL_64) (((EIF_INTEGER_32) -1L));
	*(EIF_REAL_64 *)(Current+ _R64OFF_5_0_0_0_0_0_0_3_) = (EIF_REAL_64) tr8_1;
	RTLE;
}

/* {DESCENDANTS_FILTER}.copy_value */
void F502_7056 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REAL_64 tr8_1;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTGC;
	tr8_1 = *(EIF_REAL_64 *)(RTCW(arg1) + O6622[Dtype(arg1)-485]);
	*(EIF_REAL_64 *)(Current+ _R64OFF_5_0_0_0_0_0_0_1_) = (EIF_REAL_64) tr8_1;
	RTLE;
}

/* {DESCENDANTS_FILTER}.set_value_range */
void F502_7058 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REAL_64 tr8_1;
	RTLD;
	
	RTLI(4);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLR(3,arg2);
	RTLIU(4);
	
	RTGC;
	loc1 = RTCCL(arg1);
	loc1 = RTRV(eif_new_type(2020, 0x00), loc1);
	tr8_1 = *(EIF_REAL_64 *)(RTCW(loc1)+ _R64OFF_0_0_0_0_0_0_0_0_);
	*(EIF_REAL_64 *)(Current+ _R64OFF_5_0_0_0_0_0_0_2_) = (EIF_REAL_64) tr8_1;
	loc1 = RTCCL(arg2);
	loc1 = RTRV(eif_new_type(2020, 0x00), loc1);
	tr8_1 = *(EIF_REAL_64 *)(RTCW(loc1)+ _R64OFF_0_0_0_0_0_0_0_0_);
	*(EIF_REAL_64 *)(Current+ _R64OFF_5_0_0_0_0_0_0_3_) = (EIF_REAL_64) tr8_1;
	RTLE;
}

/* {DESCENDANTS_FILTER}.set_value */
void F502_7059 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REAL_64 tr8_1;
	RTLD;
	
	RTLI(3);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLIU(3);
	
	RTGC;
	loc1 = RTCCL(arg1);
	loc1 = RTRV(eif_new_type(2020, 0x00), loc1);
	tr8_1 = *(EIF_REAL_64 *)(RTCW(loc1)+ _R64OFF_0_0_0_0_0_0_0_0_);
	*(EIF_REAL_64 *)(Current+ _R64OFF_5_0_0_0_0_0_0_0_) = (EIF_REAL_64) tr8_1;
	RTLE;
}

/* {DESCENDANTS_FILTER}.equal_to */
EIF_BOOLEAN F502_7060 (EIF_REFERENCE Current)
{
	GTCX
	
	
	return (EIF_BOOLEAN) (EIF_BOOLEAN)(*(EIF_REAL_64 *)(Current+ _R64OFF_5_0_0_0_0_0_0_1_) == *(EIF_REAL_64 *)(Current+ _R64OFF_5_0_0_0_0_0_0_0_));
}

/* {DESCENDANTS_FILTER}.less_than */
EIF_BOOLEAN F502_7064 (EIF_REFERENCE Current)
{
	GTCX
	
	
	return (EIF_BOOLEAN) (EIF_BOOLEAN) (*(EIF_REAL_64 *)(Current+ _R64OFF_5_0_0_0_0_0_0_1_) < *(EIF_REAL_64 *)(Current+ _R64OFF_5_0_0_0_0_0_0_0_));
}

/* {DESCENDANTS_FILTER}.in_interval */
EIF_BOOLEAN F502_7065 (EIF_REFERENCE Current)
{
	GTCX
	
	
	return (EIF_BOOLEAN) (EIF_BOOLEAN) ((EIF_BOOLEAN) (*(EIF_REAL_64 *)(Current+ _R64OFF_5_0_0_0_0_0_0_2_) <= *(EIF_REAL_64 *)(Current+ _R64OFF_5_0_0_0_0_0_0_1_)) && (EIF_BOOLEAN) (*(EIF_REAL_64 *)(Current+ _R64OFF_5_0_0_0_0_0_0_1_) <= *(EIF_REAL_64 *)(Current+ _R64OFF_5_0_0_0_0_0_0_3_)));
}

void EIF_Minit445 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C9/de445.c <==
/*
 * Code for class DESCENDANTS_FILTER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "de445.h"
#include "eif_helpers.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {DESCENDANTS_FILTER}.make */
void F495_7158 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REAL_64 tr8_1;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	tr8_1 = (EIF_REAL_64) (((EIF_INTEGER_32) -1L));
	*(EIF_REAL_64 *)(Current+ _R64OFF_5_0_0_0_0_0_0_0_) = (EIF_REAL_64) tr8_1;
	tr8_1 = (EIF_REAL_64) (((EIF_INTEGER_32) -1L));
	*(EIF_REAL_64 *)(Current+ _R64OFF_5_0_0_0_0_0_0_2_) = (EIF_REAL_64) tr8_1;
	tr8_1 = (EIF_REAL_64) (((EIF_INTEGER_32) -1L));
	*(EIF_REAL_64 *)(Current+ _R64OFF_5_0_0_0_0_0_0_3_) = (EIF_REAL_64) tr8_1;
	RTLE;
}

/* {DESCENDANTS_FILTER}.copy_value */
void F495_7159 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REAL_64 tr8_1;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTGC;
	tr8_1 = *(EIF_REAL_64 *)(RTCW(arg1) + O6792[Dtype(arg1)-497]);
	*(EIF_REAL_64 *)(Current+ _R64OFF_5_0_0_0_0_0_0_1_) = (EIF_REAL_64) tr8_1;
	RTLE;
}

/* {DESCENDANTS_FILTER}.set_value_range */
void F495_7161 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REAL_64 tr8_1;
	RTLD;
	
	RTLI(4);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLR(3,arg2);
	RTLIU(4);
	
	RTGC;
	loc1 = RTCCL(arg1);
	loc1 = RTRV(eif_new_type(2042, 0x00), loc1);
	tr8_1 = *(EIF_REAL_64 *)(RTCW(loc1)+ _R64OFF_0_0_0_0_0_0_0_0_);
	*(EIF_REAL_64 *)(Current+ _R64OFF_5_0_0_0_0_0_0_2_) = (EIF_REAL_64) tr8_1;
	loc1 = RTCCL(arg2);
	loc1 = RTRV(eif_new_type(2042, 0x00), loc1);
	tr8_1 = *(EIF_REAL_64 *)(RTCW(loc1)+ _R64OFF_0_0_0_0_0_0_0_0_);
	*(EIF_REAL_64 *)(Current+ _R64OFF_5_0_0_0_0_0_0_3_) = (EIF_REAL_64) tr8_1;
	RTLE;
}

/* {DESCENDANTS_FILTER}.set_value */
void F495_7162 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REAL_64 tr8_1;
	RTLD;
	
	RTLI(3);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLIU(3);
	
	RTGC;
	loc1 = RTCCL(arg1);
	loc1 = RTRV(eif_new_type(2042, 0x00), loc1);
	tr8_1 = *(EIF_REAL_64 *)(RTCW(loc1)+ _R64OFF_0_0_0_0_0_0_0_0_);
	*(EIF_REAL_64 *)(Current+ _R64OFF_5_0_0_0_0_0_0_0_) = (EIF_REAL_64) tr8_1;
	RTLE;
}

/* {DESCENDANTS_FILTER}.equal_to */
EIF_BOOLEAN F495_7163 (EIF_REFERENCE Current)
{
	GTCX
	
	
	return (EIF_BOOLEAN) (EIF_BOOLEAN) eif_is_equal_real_64 (*(EIF_REAL_64 *)(Current+ _R64OFF_5_0_0_0_0_0_0_1_), *(EIF_REAL_64 *)(Current+ _R64OFF_5_0_0_0_0_0_0_0_));
}

/* {DESCENDANTS_FILTER}.less_than */
EIF_BOOLEAN F495_7167 (EIF_REFERENCE Current)
{
	GTCX
	
	
	return (EIF_BOOLEAN) (EIF_BOOLEAN) eif_is_less_real_64 (*(EIF_REAL_64 *)(Current+ _R64OFF_5_0_0_0_0_0_0_1_), *(EIF_REAL_64 *)(Current+ _R64OFF_5_0_0_0_0_0_0_0_));
}

/* {DESCENDANTS_FILTER}.in_interval */
EIF_BOOLEAN F495_7168 (EIF_REFERENCE Current)
{
	GTCX
	
	
	return (EIF_BOOLEAN) (EIF_BOOLEAN) ((EIF_BOOLEAN) eif_is_less_equal_real_64 (*(EIF_REAL_64 *)(Current+ _R64OFF_5_0_0_0_0_0_0_2_), *(EIF_REAL_64 *)(Current+ _R64OFF_5_0_0_0_0_0_0_1_)) && (EIF_BOOLEAN) eif_is_less_equal_real_64 (*(EIF_REAL_64 *)(Current+ _R64OFF_5_0_0_0_0_0_0_1_), *(EIF_REAL_64 *)(Current+ _R64OFF_5_0_0_0_0_0_0_3_)));
}

void EIF_Minit445 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
